@@ -10,11 +10,12 @@ from SharedData.SharedDataRealTime import SharedDataRealTime
 
 class SharedData:
     
-    def __init__(self, database, mode='rw', user='master', debug=False):
-        self.debug=debug
+    def __init__(self, database, mode='rw', user='master'):        
+        
         if Logger.log is None:            
             Logger('SharedData')
-        if debug:
+
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('Initializing SharedData %s,%s,%s ...' % (user,database,mode))
         
         self.database = database        
@@ -60,8 +61,7 @@ class SharedData:
         if not collection in self.metadata.keys():              
             self.metadata[collection] = Metadata(collection,\
                 mode=self.mode,\
-                user=self.user,\
-                debug = self.debug)
+                user=self.user)
         return self.metadata[collection]
 
     def getSymbols(self, collection):        
