@@ -11,10 +11,8 @@ import pytz
 
 from SharedData.Logger import Logger
 
-debug=False
-
 def S3SyncDownloadDataFrame(path,shm_name):
-    if debug:
+    if os.environ['LOG_LEVEL']=='DEBUG':
         Logger.log.debug('AWS S3 Sync DataFrame %s...' % (shm_name))    
 
     awsfolder = os.environ['S3_BUCKET']+'/'
@@ -39,13 +37,13 @@ def S3SyncDownloadDataFrame(path,shm_name):
                 & (process.poll() is not None):
             break        
         if (output) and not (output.startswith('Completed')):
-            if debug:
+            if os.environ['LOG_LEVEL']=='DEBUG':
                 Logger.log.debug('AWSCLI:'+output.strip())  
 
     rc = process.poll()
     success= rc==0
     if success:
-        if debug:
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('AWS S3 Sync DataFrame %s,%s DONE!' % (Logger.user,shm_name))
     else:
         Logger.log.error('AWS S3 Sync DataFrame %s,%s ERROR!' % (Logger.user,shm_name))
@@ -70,13 +68,13 @@ def S3SyncDownloadTimeSeries(path,shm_name):
                 & (process.poll() is not None):
             break    
         if (output) and not (output.startswith('Completed')):
-            if debug:
+            if os.environ['LOG_LEVEL']=='DEBUG':
                 Logger.log.debug('AWSCLI:'+output.strip())        
 
     rc = process.poll()
     success= rc==0
     if success:
-        if debug:
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('AWS S3 Sync timeseries %s,%s DONE!' % (Logger.user,shm_name))
 
     else:
@@ -86,7 +84,7 @@ def S3SyncDownloadTimeSeries(path,shm_name):
 
 def S3SyncDownloadMetadata(pathpkl,name):
     
-    if debug:
+    if os.environ['LOG_LEVEL']=='DEBUG':
         Logger.log.debug('AWS S3 Sync download metadata %s...' % (name))
     folder=str(pathpkl.parents[0]).replace(\
         os.environ['DATABASE_FOLDER'],'')
@@ -115,13 +113,13 @@ def S3SyncDownloadMetadata(pathpkl,name):
                 & (process.poll() is not None):
             break        
         if (output) and not (output.startswith('Completed')):
-            if debug:
+            if os.environ['LOG_LEVEL']=='DEBUG':
                 Logger.log.debug('AWSCLI:'+output.strip())  
             
     rc = process.poll()
     success= rc==0
     if success:
-        if debug:
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('AWS S3 Sync download metadata %s,%s DONE!' % (Logger.user,name))
     else:
         Logger.log.error('AWS S3 Sync download metadata %s,%s ERROR!' % (Logger.user,name))
@@ -134,14 +132,14 @@ def S3Upload(localfilepath):
     remotefilepath = remotefilepath.replace('\\','/')        
     localfilepath = str(localfilepath).replace('\\','/')              
       
-    if debug:
+    if os.environ['LOG_LEVEL']=='DEBUG':
         Logger.log.debug(Logger.user+' Uploading to S3 '+str(localfilepath)+' ...')
     try:                
         session = boto3.Session()
         s3 = session.resource('s3')
         bucket = s3.Bucket(os.environ['S3_BUCKET'].replace('s3://',''))
         bucket.upload_file(localfilepath,remotefilepath.replace(os.environ['S3_BUCKET'],'')[1:])
-        if debug:
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug(Logger.user+' Uploading to S3 '+str(localfilepath)+' DONE!')
     except Exception as e:
         Logger.log.error(Logger.user+' Uploading to S3 '+localfilepath+' ERROR! %s' % str(e))
\ No newline at end of file
